<?php

namespace Drupal\rift\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\Yaml\Yaml;

/**
 * Configure Responsive Image Twig Filter settings for this site.
 */
class RiftSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'rift_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['rift.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['config'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Default Config'),
      '#attributes' => ['data-yaml-editor' => 'true'],
      '#default_value' => Yaml::dump($this->config('rift.settings')->get('config')),
    ];
    $form['view_modes'] = [
      '#type' => 'textarea',
      '#title' => $this->t('View Modes'),
      '#attributes' => ['data-yaml-editor' => 'true'],
      '#default_value' => Yaml::dump($this->config('rift.settings')->get('view_modes')),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('rift.settings')
      ->set('config', Yaml::parse($form_state->getValue('config')))
      ->set('view_modes', Yaml::parse($form_state->getValue('view_modes')))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
