<?php

namespace Drupal\rift;

use Drupal\Component\Plugin\Exception\PluginException;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\Core\Plugin\Discovery\ContainerDerivativeDiscoveryDecorator;
use Drupal\Core\Plugin\Discovery\YamlDiscovery;
use Drupal\locale\StringStorageInterface;

class RiftPictureViewModes extends DefaultPluginManager {

  /**
   * @var \Drupal\locale\StringStorageInterface
   */
  protected $localStorage;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs a new BananaDashboardManager object.
   *
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   Cache backend instance to use.
   * @param \Drupal\locale\StringStorageInterface $local_storage
   *   Locale string storage.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Config factory to get view modes from settings.
   */
  public function __construct(\Traversable $namespaces,
                              ModuleHandlerInterface $module_handler,
                              CacheBackendInterface $cache_backend,
                              StringStorageInterface $local_storage,
                              ConfigFactoryInterface $config_factory) {
    // Add more services as required.
    $this->moduleHandler = $module_handler;
    $this->localStorage = $local_storage;
    $this->configFactory = $config_factory;
    $this->setCacheBackend($cache_backend, 'rift_picture_view_modes', ['rift_picture_view_modes']);
    parent::__construct(FALSE, $namespaces, $module_handler);
  }

  /**
   * {@inheritdoc}
   */
  protected function getDiscovery() {
    if (!isset($this->discovery)) {
      $this->discovery = new YamlDiscovery('rift_picture_view_modes', $this->moduleHandler->getModuleDirectories());
      // $this->discovery->addTranslatableProperty('string', 'string_context');
      $this->discovery = new ContainerDerivativeDiscoveryDecorator($this->discovery);
    }
    return $this->discovery;
  }

  /**
   * {@inheritdoc}
   */
  public function getDefinitions() {
    $definitions = parent::getDefinitions();
    $settings = $this->configFactory->get('rift.settings');
    $view_modes = $settings->get('view_modes');
    if (!empty($view_modes)) {
      foreach ($view_modes as $id => $definition) {
        $definitions[$id] = $definition;
      }
    }
    return $definitions;
  }

}
